@@ -8,7 +8,7 @@ import numpy as np
 
 
 from numcodecs.abc import Codec
-from numcodecs.compat import buffer_copy
+from numcodecs.compat import buffer_copy, handle_datetime
 
 
 class BZ2(Codec):
@@ -28,6 +28,9 @@ class BZ2(Codec):
 
     def encode(self, buf):
 
+        # deal with lack of buffer support for datetime64 and timedelta64
+        buf = handle_datetime(buf)
+
         # if numpy array, can only handle C contiguous directly
         if isinstance(buf, np.ndarray) and not buf.flags.c_contiguous:
             buf = buf.tobytes(order='A')
